@@ -25,7 +25,7 @@ class BitmexClient:
     def get_position(self, symbol, prop):
         try:
             return self.client.Position.Position_get(
-            filter=json.dumps({'symbol': symbol})).result()[0][0][str(prop)]
+                filter=json.dumps({'symbol': symbol})).result()[0][0][str(prop)]
         except IndexError:
             return False
 
@@ -69,10 +69,10 @@ class BitmexClient:
                 # now = datetime.datetime.utcnow()
                 # print('Current price expired error. Time:', now, ' Server Time:', now.strftime("%m/%d/%Y, %H:%M:%S"), 'Returning last price.', flush=True)
                 print('Current price expired error. Returning last price.', flush=True)
-            return self._last_currentprice[symbol]
+            return self.last_current_price(symbol)
 
     def last_current_price(self, symbol):
-        if self._last_currentprice:
+        if symbol in self._last_currentprice.keys():
             return self._last_currentprice[symbol]
         else:
             time.sleep(2)
@@ -120,24 +120,45 @@ class BitmexOrder:
 
     def check_open_bot_order(self, symbol, entry, sl):
         settings = pickle.load(open(self._settings_path, 'rb'))
-        self.props[symbol]['stoploss_id'] = settings.symbols[symbol]['last_order_id']
+        self.props[symbol]['stoploss_id'] = settings.symbols[symbol]['last_order_stoploss_id']
+        self.props[symbol]['stop_id'] = settings.symbols[symbol]['last_order_stop_id']
         if self.props[symbol]['stoploss_id']:
             try:
                 res = self.client.client.Order.Order_getOrders(
                     filter=json.dumps({"symbol": symbol, "open": True})).result()
-                if self.props[symbol]['stoploss_id'] in [order['clOrdID'] for order in res[0]]:
-                    print("Bot order open, stoploss might be modified", flush=True)
+                if res[0] and self.props[symbol]['stoploss_id'] in [order['clOrdID'] for order in res[0]]:
+                    print("Bot order in {} open, stoploss might be modified".format(
+                        symbol), flush=True)
                     self.modifiy_stop(symbol, sl)
                     self.props[symbol]['entry'] = entry
                     self.props[symbol]['open'] = True
+                    time.sleep(2)
+            except HTTPBadRequest as e:
+                print("Error getting orders.", e)
+        if self.props[symbol]['stop_id']:
+            try:
+                res = self.client.client.Order.Order_getOrders(
+                    filter=json.dumps({"symbol": symbol, "open": True})).result()
+                if res[0] and self.props[symbol]['stop_id'] in [order['clOrdID'] for order in res[0]]:
+                    print("Bot order in {} open, stop will be deleted.".format(
+                        symbol), flush=True)
+                    self.stoporder_cancel(symbol)
+                    time.sleep(2)
             except HTTPBadRequest as e:
                 print("Error getting orders.", e)
 
-    def save_open_id(self, symbol, id):
-        self.props[symbol]['stoploss_id'] = id
+    def save_open_id(self, symbol, id, stop_type='normal'):
         settings = pickle.load(open(self._settings_path, 'rb'))
-        settings.symbols[symbol]['last_order_id'] = id
-        pickle.dump(settings, file=open(self._settings_path, 'wb'))
+        if stop_type == 'normal':
+            self.props[symbol]['stoploss_id'] = id
+            settings.symbols[symbol]['last_order_stop_id'] = id
+            pickle.dump(settings, file=open(self._settings_path, 'wb'))
+        elif stop_type == 'stoploss':
+            self.props[symbol]['stop_id'] = id
+            settings.symbols[symbol]['last_order_stoploss_id'] = id
+            pickle.dump(settings, file=open(self._settings_path, 'wb'))
+        else:
+            print("No Stop Type given.")
 
     def manage_entries(self, symbols):
         for symbol in symbols:
@@ -147,26 +168,26 @@ class BitmexOrder:
                 if self.props[symbol]['qty'] > 0 and cp >= self.props[symbol]['entry'] and self.client.open_contracts(symbol) != 0:
                     self.props[symbol]['wait_stop'] = False
                     self.props[symbol]['open'] = True
-                    print("Long Position has been opened, amending Stoploss to",
+                    print("Long Position has been opened in {}, amending Stoploss to".format(symbol),
                           self.props[symbol]['SL'], flush=True)
                     self.stoploss_order(symbol)
                 elif self.props[symbol]['qty'] < 0 and cp <= self.props[symbol]['entry'] and self.client.open_contracts(symbol) != 0:
                     self.props[symbol]['wait_stop'] = False
                     self.props[symbol]['open'] = True
-                    print("Short Position has been opened, amending Stoploss to",
+                    print("Short Position has been opened in {}, amending Stoploss to".format(symbol),
                           self.props[symbol]['SL'], flush=True)
                     self.stoploss_order(symbol)
             elif self.props[symbol]['open']:
                 if self.props[symbol]['qty'] > 0 and cp <= self.props[symbol]['SL'] and self.client.open_contracts(symbol) == 0:
                     self.props[symbol]['open'] = False
                     self.props[symbol]['qty'] = 0
-                    print("Long Position closed. {} Contracts from {} to {}. PnL in Points: {}".format(
-                        self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
+                    print("Long Position {} closed. {} Contracts from {} to {}. PnL in Points: {}".format(symbol,
+                                                                                                          self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
                 elif self.props[symbol]['qty'] < 0 and cp >= self.props[symbol]['SL'] and self.client.open_contracts(symbol) == 0:
                     self.props[symbol]['open'] = False
                     self.props[symbol]['qty'] = 0
-                    print("Short Position closed. {} Contracts from {} to {}. PnL in Points: {}".format(
-                        -self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
+                    print("Short Position {} closed. {} Contracts from {} to {}. PnL in Points: {}".format(symbol,
+                                                                                                           -self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
                 else:
                     self.props[symbol]['open'] = False
 
@@ -210,9 +231,9 @@ class BitmexOrder:
         try:
             self.props[symbol]['stoploss_id'] = self.generate_id(
                 symbol, _type='SL')
-            self.save_open_id(symbol, self.props[symbol]['stoploss_id'])
+            self.save_open_id(symbol, self.props[symbol]['stoploss_id'], stop_type='stoploss')
             return self.client.client.Order.Order_new(
-                symbol=self.symbol, ordType='Stop', clOrdID=self.StoplossID, orderQty=-self.props[symbol]['qty'],
+                symbol=symbol, ordType='Stop', clOrdID=self.props[symbol]['stoploss_id'], orderQty=-self.props[symbol]['qty'],
                 stopPx=self.price_decimals(symbol, self.props[symbol]['SL']), execInst=execPrice
             ).result()
         except HTTPBadRequest as e:
@@ -241,6 +262,7 @@ class BitmexOrder:
                 symbol=symbol, ordType='Stop', clOrdID=self.props[symbol]['stop_id'], orderQty=orderQty,
                 stopPx=self.price_decimals(symbol, entry), execInst='LastPrice'
             ).result()
+            self.save_open_id(symbol, self.props[symbol]['stop_id'])
             self.props[symbol]['qty'] = orderQty
             self.props[symbol]['wait_stop'] = True
             self.props[symbol]['SL'] = sl
@@ -281,7 +303,7 @@ class BitmexOrder:
             try:
                 res = self.client.client.Order.Order_amend(
                     orderID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
-                                                                                       newPrice)
+                                                                                          newPrice)
                 ).result()
                 return res
             except HTTPBadRequest as e:
