@@ -69,6 +69,7 @@ class Lotus:
 
     def process_signals(self, start=False):
         ns = self.get_api_signal()  # new signals
+        print(ns, flush=True)
         if ns:
             for symbol in self.symbols:
                 entry = ns[symbol]['entry']
@@ -119,7 +120,7 @@ class Lotus:
                                     print('Error closing {} order.'.format(
                                         symbol), flush=True)
                             else:
-                                cp = self.client.last_current_price
+                                cp = self.client.last_current_price(symbol)
                                 if cp > entry:
                                     sl_dist = abs(entry-cp)
                                     if sl_dist > 0.15 * sl_dist:
